@@ -210,6 +210,7 @@ class JasminSMPPConnector(object):
     validity: int = None
     requeue_delay: int = None
     host: str = None
+    host_src: str = None
     src_npi: int = None
     trx_to: int = None
     logfile: str = None
@@ -249,44 +250,44 @@ class JasminSMPPConnector(object):
     @classmethod
     def from_inspect(cls, line: List[List[str]]):
         connector = cls()
-        connector.con_fail_delay = line[16][-1]
+        connector.con_fail_delay = line[17][-1]
         connector.dlr_expiry = line[-6][-1]
         connector.coding = line[-9][-1]
         connector.submit_throughput = line[-7][-1]
         connector.elink_interval = line[11][-1]
-        connector.bind_to = line[10][-1]
-        connector.port = line[2][-1]
+        connector.bind_to = line[12][-1]
+        connector.port = line[3][-1]
         connector.con_fail_retry = line[-4][-1]
-        connector.password = line[5][-1]
-        connector.src_addr = line[24][-1]
-        connector.bind_npi = line[14][-1]
-        connector.addr_range = line[23][-1]
-        connector.dst_ton = line[22][-1]
-        connector.res_to = line[12][-1]
-        connector.def_msg_id = line[31][-1]
-        connector.priority = line[26][-1]
-        connector.con_loss_retry = line[13][-1]
-        connector.username = line[3][-1]
+        connector.password = line[6][-1]
+        connector.src_addr = line[25][-1]
+        connector.bind_npi = line[15][-1]
+        connector.addr_range = line[24][-1]
+        connector.dst_ton = line[23][-1]
+        connector.res_to = line[13][-1]
+        connector.def_msg_id = line[30][-1]
+        connector.priority = line[27][-1]
+        connector.con_loss_retry = line[14][-1]
+        connector.username = line[4][-1]
         connector.dst_npi = line[-3][-1]
-        connector.validity = line[29][-1]
+        connector.validity = line[28][-1]
         connector.requeue_delay = line[-8][-1]
         connector.host = line[1][-1]
-        connector.src_npi = line[21][-1]
+        connector.src_npi = line[22][-1]
         connector.trx_to = line[-2][-1]
-        connector.logfile = line[7][-1]
-        connector.systype = line[6][-1]
+        connector.logfile = line[8][-1]
+        connector.systype = line[7][-1]
         connector.cid = line[0][-1]
-        connector.loglevel = line[8][-1]
-        connector.bind = line[18][-1]
-        connector.proto_id = line[25][-1]
-        connector.con_loss_delay = line[15][-1]
-        connector.bind_ton = line[19][-1]
-        connector.pdu_red_to = line[17][-1]
-        connector.src_ton = line[20][-1]
-        connector.logrotate = line[4][-1]
-        connector.logprivacy = line[9][-1]
-        connector.ripf = line[30][-1]
+        connector.loglevel = line[9][-1]
+        connector.bind = line[19][-1]
+        connector.proto_id = line[26][-1]
+        connector.con_loss_delay = line[16][-1]
+        connector.bind_ton = line[20][-1]
+        connector.pdu_red_to = line[18][-1]
+        connector.src_ton = line[21][-1]
+        connector.logrotate = line[5][-1]
+        connector.logprivacy = line[10][-1]
+        connector.ripf = line[29][-1]
         connector.dlr_msgid = line[-5][-1]
-        connector.ssl = line[1][-1]
+        connector.ssl[-1][-1]
 
         return connector
